import express from 'express';
import cors from 'cors';
import { AppRouter } from './routes';
import { NODE_ENV, PORT, ORIGIN, CREDENTIALS } from '@config';

export class App {
  public app: express.Application;
  public env: string;
  public port: string | number;

  constructor() {
    this.app = express();
    this.env = NODE_ENV || 'development';
    this.port = PORT || 8080;

    this.initializeMiddlewares();
    this.initializeRoutes();
    this.initializeView();
  }

  initializeView() {
    this.app.set("views", __dirname + "/views");
    this.app.set("view engine", "ejs");
  }

  initializeMiddlewares() {
    this.app.use(
      cors({
        origin: ORIGIN,
        credentials: CREDENTIALS,
      }),
    );
    this.app.use(express.json());
    this.app.use(express.urlencoded({ extended: true }));
  }

  initializeRoutes() {
    const appRouter = new AppRouter();
    this.app.use('/', appRouter.router);
  }

  listen() {
    this.app.listen(this.port, () => {
      console.log(`Server is running on port ${this.port}`);
    });
  }
}
