import { HttpStatusCode } from '@constants/http.enum';
import { ResponseHelper } from '@helpers/response.helper';
import { RequestWithUser } from '@interfaces/auth.interface';
import { User } from '@prisma/client';
import { UserService } from '@services/user.service';
import { Response } from 'express';

export class UserController {
  constructor(private userService: UserService) {
    this.addUserFromService = this.addUserFromService.bind(this);
    this.resetPasswordFromService = this.resetPasswordFromService.bind(this);
  }

  public async addUserFromService(req: RequestWithUser, res: Response) {
    const userData: User = req.body;
    const newUser = await this.userService.addUser(userData);

    return ResponseHelper.responseSuccess(
      res, 
      HttpStatusCode.Ok, 
      'User added successful',
      newUser
    );
  }

  public async resetPasswordFromService(req: RequestWithUser, res: Response){
    const {user_id} = req.user 
    const password = req.body.password;

    const newPassword = await this.userService.resetPassword(user_id, password);

    return ResponseHelper.responseSuccess(
      res, 
      HttpStatusCode.Ok, 
      'Reset Password Success',
      newPassword
    );
  }


}
