import { AuthController } from '@controllers/auth.controller';
import { Routes } from '@interfaces/route.interface';
import { ValidationMiddleware } from '@middlewares/index';
import { AuthService } from '@services/auth.service';
import { loginSchema } from '@dtos/auth.dto';
import { Router } from 'express';

export class AuthRoute implements Routes {
  public router = Router();
  private authService = new AuthService();
  private authController = new AuthController(this.authService);

  constructor() {
    this.initializeRoutes();
  }

  private initializeRoutes() {
    this.router.get(
      '/login', 
      ValidationMiddleware.exceptionGuard(this.authController.login)
    );

    this.router.post(
      '/login', 
      ValidationMiddleware.validate(loginSchema), 
      ValidationMiddleware.exceptionGuard(this.authController.dologin)
    );
  }
}
